@@ -28,51 +28,30 @@ def enter_and_leave_function(func: Callable) -> Callable:
 
     @functools.wraps(func)  # 保留原函数元信息（如 __name__、__doc__）
     def wrapper(*args: Any, **kwargs: Any) -> Any:
-        # --------------------------
-        # 1. 函数调用前：记录入参 + 函数定义位置
-        # --------------------------
         # 获取函数定义的文件路径和行号（基础位置信息）
         func_def_file = inspect.getsourcefile(func) or "unknown_file"
         func_def_line = inspect.getsourcelines(func)[1] if func_def_file != "unknown_file" else "unknown_line"
-
-        # 格式化入参（避免复杂对象打印过长，简化显示）
-        args_str = _format_args(args)
-        kwargs_str = _format_kwargs(kwargs)
-
         log.info(
-            f"[函数调用] 开始执行 {func.__name__}() "
-            f"| 定义位置：{func_def_file}:{func_def_line} "
-            f"| 入参：args={args_str}, kwargs={kwargs_str}"
+            f"[{func_def_file}:{func_def_line}]"
+            f"[{func.__name__}()]"
+            f"| args={args}, kwargs={kwargs}"
         )
 
         try:
-            # --------------------------
-            # 2. 执行原函数
-            # --------------------------
             result = func(*args, **kwargs)
-
-            # --------------------------
-            # 3. 函数正常返回：记录返回值
-            # --------------------------
-            result_str = _format_result(result)
             log.info(
-                f"[函数调用] 成功执行 {func.__name__}() "
-                f"| 返回值：{result_str}"
+                f"| finish run function {func.__name__}(), return value is: {result} "
             )
             return result
 
         except Exception as e:
-            # --------------------------
-            # 4. 函数异常：记录完整堆栈（含函数内报错行数）
-            # --------------------------
-            # 获取异常堆栈信息（格式化为字符串，包含具体代码行）
             error_traceback = traceback.format_exc()
 
             log.error(
-                f"[函数调用] 执行 {func.__name__}() 失败 "
-                f"| 错误类型：{type(e).__name__} "
-                f"| 错误信息：{str(e)} "
-                f"| 完整堆栈：\n{error_traceback}",
+                f"failed to run function {func.__name__}() :Failed. "
+                f"| error_type：{type(e).__name__} "
+                f"| error_message：{str(e)} "
+                f"| full_stack_trace：\n{error_traceback}",
                 exc_info=False  # 已手动捕获堆栈，避免 logging 重复打印
             )
             raise  # 重新抛出异常，不中断原异常链路
@@ -80,42 +59,6 @@ def enter_and_leave_function(func: Callable) -> Callable:
     return wrapper
 
 
-# --------------------------
-# 辅助函数：格式化入参/返回值（避免打印过长或乱码）
-# --------------------------
-def _format_args(args: tuple) -> str:
-    """格式化位置参数（简化复杂对象显示）"""
-    formatted = []
-    for arg in args:
-        # 对过长的字符串/列表/字典进行截断
-        if isinstance(arg, (str, list, tuple, dict, set)):
-            arg_str = str(arg)
-            formatted.append(arg_str[:100] + "..." if len(arg_str) > 100 else arg_str)
-        else:
-            formatted.append(str(arg))
-    return f"({', '.join(formatted)})"
-
-
-def _format_kwargs(kwargs: dict) -> str:
-    """格式化关键字参数"""
-    formatted = []
-    for k, v in kwargs.items():
-        if isinstance(v, (str, list, tuple, dict, set)):
-            v_str = str(v)
-            formatted_v = v_str[:100] + "..." if len(v_str) > 100 else v_str
-        else:
-            formatted_v = str(v)
-        formatted.append(f"{k}={formatted_v}")
-    return f"{{{', '.join(formatted)}}}"
-
-
-def _format_result(result: Any) -> str:
-    """格式化返回值（同入参格式化逻辑）"""
-    if isinstance(result, (str, list, tuple, dict, set)):
-        result_str = str(result)
-        return result_str[:200] + "..." if len(result_str) > 200 else result_str
-    return str(result)
-
 
 class CloudPods:
     def __init__(self,keystone_url,username,password,domain="default",project="system"):
